@@ -238,9 +238,9 @@ colortable = {b'topic.active': b'green',
               b'log.topic': b'green_background',
               }
 
-__version__ = b'1.1.4'
+__version__ = b'1.1.6'
 
-testedwith = b'4.9 5.0 5.1 5.2 5.3 5.4 5.5 5.6 5.7 5.8 5.9 6.0 6.1 6.2 6.3 6.4 6.5 6.6 6.7 6.8'
+testedwith = b'4.9 5.0 5.1 5.2 5.3 5.4 5.5 5.6 5.7 5.8 5.9 6.0 6.1 6.2 6.3 6.4 6.5 6.6 6.7 6.8 6.9'
 minimumhgversion = b'4.9'
 buglink = b'https://bz.mercurial-scm.org/'
 
